==> fas_ui_flutter-0.0.3.tar.gz: lib/components/bar/segment_bar.dart <==
import 'package:flutter/material.dart';

///单选分段组件
// ignore: must_be_immutable
class SegmentBar extends StatefulWidget {
  List<String> datas;
  Function(int) onSelected;
  int defaultIndex = 0;

  SegmentBar({@required this.datas, this.onSelected, this.defaultIndex});

  @override
  _SegmentBarState createState() => _SegmentBarState();
}

class _SegmentBarState extends State<SegmentBar> {
  List<String> sdkLists;
  int selectItemIndex;

  @override
  void initState() {
    super.initState();
    sdkLists = widget.datas;
    selectItemIndex = widget.defaultIndex;
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      scrollDirection: Axis.horizontal,
      child: Container(
        child: Row(
          children: _buildSegments(sdkLists),
        ),
      ),
    );
  }

  List<Widget> _buildSegments(List<String> datas) {
    List<Widget> items = [];
    if (datas == null || datas.length == 0) {
      items.add(SizedBox.shrink());
      return items;
    }
    for (var i = 0; i < datas.length; i++) {
      items.add(_buildItem(i));
    }
    return items;
  }

  _buildItem(int index) {
    if (selectItemIndex == index) {
      return InkWell(
        onTap: () {
          updateSelectIndex(index);
        },
        child: Container(
          margin: EdgeInsets.only(right: 28),
          decoration: BoxDecoration(boxShadow: [
            BoxShadow(
                color: Color(0x44697FFE),
                offset: Offset(0.0, 3.0), //阴影xy轴偏移量
                blurRadius: 6.0, //阴影模糊程度
                spreadRadius: 1.0 //阴影扩散程度
                )
          ], borderRadius: BorderRadius.circular(15), color: Color(0xFF697FFE)),
          alignment: Alignment.center,
          height: 30,
          width: 90,
          child: Text(
            sdkLists[index],
            style: TextStyle(color: Colors.white, fontSize: 16),
          ),
        ),
      );
    } else {
      return Container(
        alignment: Alignment.center,
        height: 30,
        width: 90,
        margin: EdgeInsets.only(right: 28),
        child: InkWell(
          onTap: () {
            updateSelectIndex(index);
          },
          child: Container(
            decoration: BoxDecoration(boxShadow: [
              BoxShadow(
                  color: Color(0x44697FFE),
                  offset: Offset(0.0, 3.0), //阴影xy轴偏移量
                  blurRadius: 6.0, //阴影模糊程度
                  spreadRadius: 1.0 //阴影扩散程度
                  )
            ], borderRadius: BorderRadius.circular(15), color: Colors.white),
            child: Text(
              sdkLists[index],
              style: TextStyle(color: Color(0xFF9FA4B9), fontSize: 16),
            ),
          ),
        ),
      );
    }
  }

  void updateSelectIndex(int index) {
    if (selectItemIndex == index) {
      return;
    } else {
      selectItemIndex = index;
      if (widget.onSelected != null) widget.onSelected(selectItemIndex);
      setState(() {});
    }
  }
}

==> fas_ui_flutter-0.0.4.tar.gz: lib/components/bar/segment_bar.dart <==
import 'package:flutter/material.dart';

///单选分段组件
// ignore: must_be_immutable
class SegmentBar extends StatefulWidget {
  List<String> datas;
  Function(int) onSelected;
  int defaultIndex = 0;

  SegmentBar({@required this.datas, this.onSelected, this.defaultIndex});

  @override
  _SegmentBarState createState() => _SegmentBarState();
}

class _SegmentBarState extends State<SegmentBar> {
  List<String> sdkLists;
  int selectItemIndex;

  @override
  void initState() {
    super.initState();
    sdkLists = widget.datas;
    selectItemIndex = widget.defaultIndex;
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      scrollDirection: Axis.horizontal,
      child: Container(
        child: Row(
          children: _buildSegments(sdkLists),
        ),
      ),
    );
  }

  List<Widget> _buildSegments(List<String> datas) {
    List<Widget> items = [];
    if (datas == null || datas.length == 0) {
      items.add(SizedBox.shrink());
      return items;
    }
    for (var i = 0; i < datas.length; i++) {
      items.add(_buildItem(i));
    }
    return items;
  }

  _buildItem(int index) {
    if (selectItemIndex == index) {
      return Container(
        margin: EdgeInsets.only(right: 28),
        child: InkWell(
          onTap: () {
            updateSelectIndex(index);
          },
          child: Container(
            decoration: BoxDecoration(
                boxShadow: [
                  BoxShadow(
                      color: Color(0x44697FFE),
                      offset: Offset(0.0, 3.0), //阴影xy轴偏移量
                      blurRadius: 6.0, //阴影模糊程度
                      spreadRadius: 1.0 //阴影扩散程度
                      )
                ],
                borderRadius: BorderRadius.circular(15),
                color: Color(0xFF697FFE)),
            alignment: Alignment.center,
            height: 30,
            width: 90,
            child: Text(
              sdkLists[index],
              style: TextStyle(color: Colors.white, fontSize: 16),
            ),
          ),
        ),
      );
    } else {
      return Container(
        alignment: Alignment.center,
        margin: EdgeInsets.only(right: 28),
        child: InkWell(
          onTap: () {
            updateSelectIndex(index);
          },
          child: Container(
            height: 30,
            width: 90,
            decoration: BoxDecoration(boxShadow: [
              BoxShadow(
                  color: Color(0x44697FFE),
                  offset: Offset(0.0, 3.0), //阴影xy轴偏移量
                  blurRadius: 6.0, //阴影模糊程度
                  spreadRadius: 1.0 //阴影扩散程度
                  )
            ], borderRadius: BorderRadius.circular(15), color: Colors.white),
            child: Text(
              sdkLists[index],
              style: TextStyle(color: Color(0xFF9FA4B9), fontSize: 16),
            ),
          ),
        ),
      );
    }
  }

  void updateSelectIndex(int index) {
    if (selectItemIndex == index) {
      return;
    } else {
      selectItemIndex = index;
      if (widget.onSelected != null) widget.onSelected(selectItemIndex);
      setState(() {});
    }
  }
}
